#!/bin/sh -e
### BEGIN INIT INFO
# Provides:          xorg
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the PlexHomeTheater
### END INIT INFO

NAME=x11vnc
PKG_PATH=/usr/local/AppCentral/x11vnc
# ASPORTAL_PATH=/usr/local/AppCentral/asportal
# ASPORTAL_STAT=$(apkg --info-installed asportal | grep 'Enabled:' | awk '{print $2}')
rcP=/usr/local/etc/init.d/P89x11vnc
CONF=/usr/local/AppCentral/x11vnc/x11vnc.conf

is_xorg_enable(){
/usr/sbin/apkg --info-installed xorg | grep Enabled | grep -q Yes
if [ $? -ne 0 ] ; then
	echo " Xorg is not Enable "
	/usr/sbin/syslog --log 0 --level 2 --user admin --event "x11vnc can't start if Xorg is disabled"
        exit 1
fi
}

if [ ! -e ${PKG_PATH}/CONTROL/env.sh ]; then
    echo "Can't find $PKG_PATH/CONTROL/env.sh"
    exit 1
fi
source ${PKG_PATH}/CONTROL/env.sh

. /lib/lsb/init-functions

start_daemon () {
	[ -e "$rcP" ] || ln -s ${PKG_PATH}/CONTROL/start-stop.sh $rcP
	is_xorg_enable
	if [ ! -e /tmp/.x11vnc_lock ] ; then
		if [ "$(/usr/bin/confutil -get $CONF param atboot)" = "TRUE" ] ; then
			${PKG_PATH}/bin/vnc_mngt start boot &
		fi
		touch /tmp/.x11vnc_lock
	else
			${PKG_PATH}/bin/vnc_mngt start &
	fi
}

stop_daemon () {
	${PKG_PATH}/bin/vnc_mngt stop
        [ -e "$rcP" ] && rm -rf $rcP
}

case "$1" in
    start)
        log_daemon_msg "Starting" "$NAME"
	start_daemon
        log_end_msg 0
        ;;
    stop)
        log_daemon_msg "Stopping" "$NAME"
	stop_daemon
        log_end_msg 0
        ;;
    restart|force-reload)
        log_daemon_msg "Restarting" "$NAME"
	stop_daemon
	sleep 1
	start_daemon
        log_end_msg 0
        ;;
    *)
        echo "Usage: start-stop.sh {start|stop|force-reload|restart}"
        exit 1
        ;;
esac

exit 0
